@@ -2,7 +2,7 @@ __all__ = ('OrderPoint',)
 
 from expressmoney.api import *
 
-SERVICE_NAME = 'loans'
+SERVICE = 'loans'
 
 
 class AmountLimitContract(Contract):
@@ -56,10 +56,13 @@ class OrderReadContract(OrderCreateContract):
     contract_demo = serializers.CharField(max_length=256, allow_blank=True)
 
 
-loans_orders_order = ID(SERVICE_NAME, 'orders', 'order')
+class OrderID(ID):
+    _service = SERVICE
+    _app = 'orders'
+    _view_set = 'order'
 
 
 class OrderPoint(ListPointMixin, CreatePointMixin, ContractPoint):
-    _point_id = loans_orders_order
+    _point_id = OrderID()
     _read_contract = OrderReadContract
     _create_contract = OrderCreateContract
