@@ -28,27 +28,13 @@ class BankCardPaymentListContract(BankCardPaymentCreateContract):
     created = serializers.DateTimeField()
 
 
-payments_payments_payment_bank_card = ID(SERVICE, 'payments', 'bank_card_payment')
+class BankCardPaymentID(ID):
+    _service = SERVICE
+    _app = 'payments'
+    _view_set = 'bank_card_payment'
 
 
 class BankCardPaymentPoint(ListPointMixin, CreatePointMixin, ContractPoint):
-    _point_id = payments_payments_payment_bank_card
+    _point_id = BankCardPaymentID()
     _create_contract = BankCardPaymentCreateContract
     _read_contract = BankCardPaymentListContract
-
-
-"""
-from django.contrib.auth import get_user_model
-User = get_user_model()
-user = User.objects.get(id=1)
-
-point = LoanPaymentBodyPoint(user)
-point.create({"amount": 100, "department": 13, "analytical": 44})
-
-from loans.models import Loan
-loan = Loan.objects.get(id=44)
-print(loan.body_balance)
-
-from expressmoney.api.payments import BankCardPaymentPoint
-point = BankCardPaymentPoint(user).create({"type": "LOAN_INTERESTS", "amount": "10", "analytical": 44, "department": 13, "bank_card": 1})
-"""
\ No newline at end of file
