@@ -43,16 +43,17 @@ class RequestError(PointError):
         self.__status_code = self.default_status_code if status_code is None else status_code
         self.__detail = self.default_detail if detail is None else detail
 
-    def __str__(self):
-        return str(self.__detail)
+    @property
+    def url(self):
+        return self.__url
+
+    @property
+    def status_code(self):
+        return self.__status_code
 
     @property
     def detail(self):
-        return {
-            'url': self.__url,
-            'status_code': self.__status_code,
-            'detail': self.__detail,
-        }
+        return self.__detail
 
 
 class ServerError(RequestError):
